===========================================
 Weihnachtsgurke: a PYCCLE-TCP Search Tool
===========================================

|docs|  |travis|

This is Weihnacktsgurke, a search tool for the PYCCLE-TCP corpus.  The
corpus and this program have been developed by `Aaron Ecay
<http://aaronecay.com>`_ under the auspices of the `Centre for
Linguistic History and Diversity
<http://www.york.ac.uk/language/research/centres/clhd/>`_ at the
University of York’s `Department of Language and Linguistic Science
<http://www.york.ac.uk/language/>`_.

It is named for the pseudo-German `Christmas pickle hunt
<https://en.wikipedia.org/wiki/Christmas_pickle>`_.

Links:

- `User’s manual <http://weihnachtsgurke.readthedocs.org/en/latest/>`_
- PYCCLE-TCP corpus page (currently non-existent)

.. |docs| image:: https://readthedocs.org/projects/weihnachtsgurke/?badge=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://readthedocs.org/projects/weihnachtsgurke/

.. |travis| image:: https://travis-ci.org/aecay/weihnachtsgurke.svg?branch=master
    :target: https://travis-ci.org/aecay/weihnachtsgurke
    :alt: Build status
    :scale: 100%
